import 'package:args/command_runner.dart';
import 'package:io/io.dart';
import 'package:mason/mason.dart';

import '../command.dart';

/// {@template install_command}
/// `mason install` command exposes the ability to install brick templates.
/// {@endtemplate}
class InstallCommand extends MasonCommand {
  /// {@macro install_command}
  InstallCommand({Logger logger}) : super(logger: logger) {
    argParser
      ..addOption(
        'path',
        help: 'Path in repository. Defaults to "/"',
      )
      ..addOption(
        'ref',
        help:
            '''Anything that git can use to identify a commit.\nCan be a branch name, tag, or commit hash.''',
      );
  }

  @override
  final String description = 'Install brick templates';

  @override
  final String name = 'install';

  @override
  List<String> get aliases => ['i'];

  @override
  Future<int> run() async {
    if (argResults.rest.isEmpty) {
      throw UsageException(
        'path to the brick template must be provided',
        usage,
      );
    }
    final installDone = logger.progress('intalling brick');
    final url = argResults.rest.first;
    final path = argResults['path'] as String;
    final ref = argResults['ref'] as String;
    final gitPath = GitPath(url, path: path, ref: ref);
    print(url);
    print(path);
    print(ref);
    await cache.downloadRemoteBrick(gitPath);
    await bricksJson.create(recursive: true);
    await bricksJson.writeAsString(cache.encode);
    installDone();
    return ExitCode.success.code;
  }
}
